#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.sauerbraten.org/

# Package name
NAME="sauerbraten"
# Package version
VERSION="20071222"
# Source code URL
SOURCE="http://downloads.sourceforge.net/sauerbraten/sauerbraten_2007_12_22_assassin_edition_linux.tar.bz2"
# Patch URL
#PATCH="http://downloads.sourceforge.net/sauerbraten/patch-2007-09-04_linux.tar.gz"

# Files that should be placed in /usr/doc/package-version/
DOCS="README.html docs"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i686"
CPU="i686"
BUILD="50.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: sauerbraten - 3D game engine and FPS/RPG game
$NAME:
$NAME: Sauerbraten (a.k.a. Cube 2) is a free multiplayer/singleplayer
$NAME: first person shooter, built as a major redesign of the Cube FPS.
$NAME: Much like the original Cube, the aim of this game is not
$NAME: necessarily to produce the most features & eyecandy possible, but
$NAME: rather to allow map/geometry editing to be done dynamically
$NAME: in-game, to create fun gameplay and an elegant engine.
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME
if [ -f sauerbraten_2007_12_22_assassin_edition_linux.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi
#if [ -f patch-2007-09-04_linux.tar.gz ]; then
	#echo "Source file already here, no need to download";
#else
 	#echo "Downloading source"
	#wget -c $PATCH
#fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvjf sauerbraten_2007_12_22_assassin_edition_linux.tar.bz2
#tar xvzf patch-2007-09-04_linux.tar.gz
tar xvzf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Sauerbraten
Exec=sauerbraten
Terminal=false
Type=Application
Categories=Game;ActionGame;
Icon=sauerbraten
EOF
cat > $PKG/usr/share/applications/$NAME-noshaders.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Sauerbraten - No shaders
Exec=sauerbraten-noshaders
Terminal=false
Type=Application
Categories=Game;ActionGame;
Icon=sauerbraten
EOF

# Create executables
mkdir -p $PKG/usr/bin
cat > $PKG/usr/bin/sauerbraten <<EOF
#!/bin/sh
cd /usr/share/$NAME
sauerbraten_unix -f1 "\%@"
EOF
cat > $PKG/usr/bin/sauerbraten-noshaders <<EOF
#!/bin/sh
cd /usr/share/$NAME
sauerbraten_unix -f0 "\%@"
EOF
chmod a+x $PKG/usr/bin/sauerbraten*

# Install on temporary directory
cd $NAME
mkdir -p $PKG/usr/share/$NAME
cp -a sauerbraten_unix bin_unix data packages $PKG/usr/share/$NAME

# Copy icons to the right place
ICONSIZES="192 128 72 64 48 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Remove some unwanted files
rm -rf $PKG/usr/share/$NAME/data/CVS

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME
rm -rf $PKG
